@@ -1,8 +1,8 @@
 import requests
 import json
 
-def create(uploadType, shot, resourceId, filePath):
-    url = "http://3.39.12.67:8083/qcc/job"
+def create(url, uploadType, shot, resourceId, filePath, volumeName):
+    url_path = f"{url}/qcc/job"
 
     headers = {
         #"Content-Type": "application/x-www-form-urlencoded"
@@ -13,29 +13,30 @@ def create(uploadType, shot, resourceId, filePath):
         "uploadType": uploadType,
         "shot": shot,
         "resourceId": resourceId,
-        "filePath": filePath
+        "filePath": filePath,
+        "volumeName": volumeName
     })
 
     # params = {
     #     "namespace": f"{nameSpace}"
     # }
 
-    response = requests.post(f"{url}", headers=headers, data=data) 
+    response = requests.post(f"{url_path}", headers=headers, data=data) 
 
-    print("[CREATE] ",response.text, flush=True)
+    print("[Job CREATE] ",response.text, flush=True)
 
     return response.text
 
-def getList():
-    url = "http://3.39.12.67:8083/qcc/jobs"
+def getList(url):
+    url_path = f"{url}/qcc/jobs"
 
     # params = {
     #     "volumeName": volumeName,
     #     "hostPath": hostPath
     # }
 
-    response = requests.get(f"{url}") # , params=params)
+    response = requests.get(f"{url_path}") # , params=params)
 
-    print("[LIST] ", response.text, flush=True)
+    print("[Job LIST] ", response.text, flush=True)
 
     return response.text
